        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 15 <strong>control</strong><br>0,5,9,11,12,18,19,21,23,29,30,39,42,44,45';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 15 <br>3,4,6,7,14,15,16,17,28,32,34,37,43,48,49';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 8 <br>1,20,22,25,27,35,41,50';}
       if(rr==7 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>31</strong> miembros: 7 <br>2,8,13,26,31,36,46';}
       if(rr==7 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>38</strong> miembros: 4 <br>24,33,38,40';}
       if(rr==7 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>6</strong> representante: <strong>10</strong> miembros: 2 <br>10,47';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 15 <strong>control</strong><br>0,5,9,11,12,18,19,21,23,29,30,39,42,44,45';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 15 <br>3,4,6,7,14,15,16,17,28,32,34,37,43,48,49';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 8 <br>1,20,22,25,27,35,41,50';}
       if(rr==34 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>31</strong> miembros: 7 <br>2,8,13,26,31,36,46';}
       if(rr==34 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>38</strong> miembros: 4 <br>24,33,38,40';}
       if(rr==34 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>6</strong> representante: <strong>10</strong> miembros: 2 <br>10,47';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 15 <strong>control</strong><br>0,5,9,11,12,18,19,21,23,29,30,39,42,44,45';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 15 <br>3,4,6,7,14,15,16,17,28,32,34,37,43,48,49';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 8 <br>1,20,22,25,27,35,41,50';}
       if(rr==35 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>31</strong> miembros: 7 <br>2,8,13,26,31,36,46';}
       if(rr==35 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>38</strong> miembros: 4 <br>24,33,38,40';}
       if(rr==35 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>6</strong> representante: <strong>10</strong> miembros: 2 <br>10,47';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 15 <strong>control</strong><br>0,5,9,11,12,18,19,21,23,29,30,39,42,44,45';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 15 <br>3,4,6,7,14,15,16,17,28,32,34,37,43,48,49';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 8 <br>1,20,22,25,27,35,41,50';}
       if(rr==36 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>31</strong> miembros: 7 <br>2,8,13,26,31,36,46';}
       if(rr==36 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>38</strong> miembros: 4 <br>24,33,38,40';}
       if(rr==36 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>6</strong> representante: <strong>10</strong> miembros: 2 <br>10,47';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 15 <strong>control</strong><br>0,5,9,11,12,18,19,21,23,29,30,39,42,44,45';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 15 <br>3,4,6,7,14,15,16,17,28,32,34,37,43,48,49';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 8 <br>1,20,22,25,27,35,41,50';}
       if(rr==37 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>31</strong> miembros: 7 <br>2,8,13,26,31,36,46';}
       if(rr==37 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>38</strong> miembros: 4 <br>24,33,38,40';}
       if(rr==37 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>6</strong> representante: <strong>10</strong> miembros: 2 <br>10,47';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 15 <strong>control</strong><br>0,5,9,11,12,18,19,21,23,29,30,39,42,44,45';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 15 <br>3,4,6,7,14,15,16,17,28,32,34,37,43,48,49';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 8 <br>1,20,22,25,27,35,41,50';}
       if(rr==38 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>31</strong> miembros: 7 <br>2,8,13,26,31,36,46';}
       if(rr==38 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>38</strong> miembros: 4 <br>24,33,38,40';}
       if(rr==38 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>6</strong> representante: <strong>10</strong> miembros: 2 <br>10,47';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 15 <strong>control</strong><br>0,5,9,11,12,18,19,21,23,29,30,39,42,44,45';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 15 <br>3,4,6,7,14,15,16,17,28,32,34,37,43,48,49';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>3</strong> representante: <strong>27</strong> miembros: 8 <br>1,20,22,25,27,35,41,50';}
       if(rr==39 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>4</strong> representante: <strong>31</strong> miembros: 7 <br>2,8,13,26,31,36,46';}
       if(rr==39 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>5</strong> representante: <strong>38</strong> miembros: 4 <br>24,33,38,40';}
       if(rr==39 && cc==6){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260619 a 12</strong> UTC HH+168 (rango:156-180)<br>grupo: <strong>6</strong> representante: <strong>10</strong> miembros: 2 <br>10,47';}
}
